@@ -335,6 +335,7 @@ class CfnNamedQuery(
         query_string: builtins.str,
         description: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
+        work_group: typing.Optional[builtins.str] = None,
     ) -> None:
         """Create a new ``AWS::Athena::NamedQuery``.
 
@@ -344,12 +345,14 @@ class CfnNamedQuery(
         :param query_string: ``AWS::Athena::NamedQuery.QueryString``.
         :param description: ``AWS::Athena::NamedQuery.Description``.
         :param name: ``AWS::Athena::NamedQuery.Name``.
+        :param work_group: ``AWS::Athena::NamedQuery.WorkGroup``.
         """
         props = CfnNamedQueryProps(
             database=database,
             query_string=query_string,
             description=description,
             name=name,
+            work_group=work_group,
         )
 
         jsii.create(CfnNamedQuery, self, [scope, id, props])
@@ -445,6 +448,19 @@ class CfnNamedQuery(
     def name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "name", value)
 
+    @builtins.property # type: ignore
+    @jsii.member(jsii_name="workGroup")
+    def work_group(self) -> typing.Optional[builtins.str]:
+        """``AWS::Athena::NamedQuery.WorkGroup``.
+
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-workgroup
+        """
+        return jsii.get(self, "workGroup")
+
+    @work_group.setter # type: ignore
+    def work_group(self, value: typing.Optional[builtins.str]) -> None:
+        jsii.set(self, "workGroup", value)
+
 
 @jsii.data_type(
     jsii_type="@aws-cdk/aws-athena.CfnNamedQueryProps",
@@ -454,6 +470,7 @@ class CfnNamedQuery(
         "query_string": "queryString",
         "description": "description",
         "name": "name",
+        "work_group": "workGroup",
     },
 )
 class CfnNamedQueryProps:
@@ -464,6 +481,7 @@ class CfnNamedQueryProps:
         query_string: builtins.str,
         description: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
+        work_group: typing.Optional[builtins.str] = None,
     ) -> None:
         """Properties for defining a ``AWS::Athena::NamedQuery``.
 
@@ -471,6 +489,7 @@ class CfnNamedQueryProps:
         :param query_string: ``AWS::Athena::NamedQuery.QueryString``.
         :param description: ``AWS::Athena::NamedQuery.Description``.
         :param name: ``AWS::Athena::NamedQuery.Name``.
+        :param work_group: ``AWS::Athena::NamedQuery.WorkGroup``.
 
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html
         """
@@ -482,6 +501,8 @@ class CfnNamedQueryProps:
             self._values["description"] = description
         if name is not None:
             self._values["name"] = name
+        if work_group is not None:
+            self._values["work_group"] = work_group
 
     @builtins.property
     def database(self) -> builtins.str:
@@ -521,6 +542,15 @@ class CfnNamedQueryProps:
         result = self._values.get("name")
         return result
 
+    @builtins.property
+    def work_group(self) -> typing.Optional[builtins.str]:
+        """``AWS::Athena::NamedQuery.WorkGroup``.
+
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-workgroup
+        """
+        result = self._values.get("work_group")
+        return result
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
